@@ -31,6 +31,10 @@ QVariant EmojiModel::data(const QModelIndex &index, int role) const
     if (index.row() < mEmoticonList.count()) {
         const auto &unicodeEmoti = mEmoticonList.at(index.row());
         switch (role) {
+        case AnimatedFileName:
+            return {};
+        case Animated:
+            return false;
         case Qt::DisplayRole:
         case UnicodeEmoji:
             return unicodeEmoti.unicode();
@@ -45,8 +49,28 @@ QVariant EmojiModel::data(const QModelIndex &index, int role) const
     } else {
         const auto &customEmoji = mCustomEmojiList.at(index.row() - mEmoticonList.count());
         switch (role) {
+        case AnimatedFileName:
+            if (mCustomEmojiIconManager) {
+                if (customEmoji.isAnimatedEmoji()) {
+                    const QString filename = mCustomEmojiIconManager->fileName(customEmoji.identifier());
+                    return filename;
+                }
+                return {};
+            } else {
+                qCWarning(TEXTEMOTICONSCORE_LOG) << "mCustomEmojiIconManager is null. It's a bug";
+                return {};
+            }
+        case Animated:
+            return customEmoji.isAnimatedEmoji();
         case Qt::DecorationRole: {
             if (mCustomEmojiIconManager) {
+                if (customEmoji.isAnimatedEmoji()) {
+                    const QString filename = mCustomEmojiIconManager->fileName(customEmoji.identifier());
+                    if (!filename.isEmpty()) {
+                        const QIcon icon(filename);
+                        return icon;
+                    }
+                }
                 const QIcon icon = mCustomEmojiIconManager->generateIcon(customEmoji.identifier());
                 return icon;
             } else {
@@ -58,9 +82,8 @@ QVariant EmojiModel::data(const QModelIndex &index, int role) const
             return customEmoji.category();
         case Order:
             return -1;
-        case Identifier:
         case Qt::ToolTipRole:
-            return customEmoji.identifier();
+        case Identifier:
         case UnicodeEmoji:
             return customEmoji.identifier();
         }
